/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.AddressLine;

import bunshin.util.ResultSortedQueue;
import dermi.DHTHandler;
import dermi.core.Id;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class AddressLineTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(AddressLineTable.class);

	static {

	}

	/**
	 * Insert new row into the ADDRESS_LINE table.
	 * 
	 * @param businessKey
	 *            BusinessKey to the BusinessEntity object that owns the Contact
	 *            to be inserted
	 * @param contactID
	 *            The unique ID generated when saving the parent Contact
	 *            instance.
	 * @param addressID
	 *            The unique ID generated when saving the parent Address
	 *            instance.
	 * @param lineList
	 *            Enumeration of AddressLines objects holding values to be
	 *            inserted.
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String businessKey, int contactID, int addressID,
			Vector lineList, DHTHandler connection) {
		if ((lineList == null) || (lineList.size() == 0))
			return; // everything is valid but no elements to insert

		AddressLine tmp = new AddressLine(businessKey, contactID, addressID,
				lineList);
		try {
			connection.insert(businessKey + " " + contactID + " " + addressID
					+ " addressline",businessKey + " " + contactID + " " + addressID
					+ " addressline", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the CONTACT table for a given BusinessKey.
	 * 
	 * @param businessKey
	 *            BusinessKey
	 * @param contactID
	 *            Unique ID representing the parent Contact instance
	 * @param connection
	 *            DHT connection
	 */

	@SuppressWarnings("unchecked")
	public static Vector select(String businessKey, int contactID,
			int addressID, DHTHandler connection) {
		ResultSortedQueue tmp = null;
		Vector lineList = new Vector();
		try {
			String txt="";
			if (businessKey != null){txt+=businessKey + " ";}
			if (contactID != 0){txt+=contactID + " ";}
			if (addressID != 0){txt+=addressID;}
			tmp = connection.query(txt + " addressline");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			try {
				lineList.add((AddressLine) connection.retrieve((Id)it.next()));
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		return lineList;
	}

	/**
	 * Delete multiple rows from the ADDRESS_LINE table that are assigned to the
	 * BusinessKey specified.
	 * 
	 * @param businessKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String businessKey, DHTHandler connection) {
		try {
			connection.remove("", businessKey + " addressline");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
