/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datatype.business.BusinessEntity;

import bunshin.util.ResultSortedQueue;
import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class BusinessEntityTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(BusinessEntityTable.class);

	static {

	}

	/**
	 * Insert new row into the BUSINESS_ENTITY table.
	 * 
	 * @param business
	 *            object holding values to be inserted
	 * @param publisherID
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(BusinessEntity business, String publisherID,
			DHTHandler connection) {
		org.apache.juddi.datastore.dht.datatype.BusinessEntity tmp = new org.apache.juddi.datastore.dht.datatype.BusinessEntity(
				business, publisherID);
		try {
			connection.insert(business.getBusinessKey() + " " + publisherID
					+ " businessentity", business.getBusinessKey()
					+ " businessentity", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Delete row from the BUSINESS_ENTITY table.
	 * 
	 * @param businessKey
	 *            key value
	 * @param connection
	 *            JDBC Connection
	 * @throws java.sql.SQLException
	 */
	public static void delete(String businessKey, DHTHandler connection) {
		try {
			connection.remove("", businessKey + " businessentity");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select one row from the BUSINESS_ENTITY table.
	 * 
	 * @param businessKey
	 *            key value
	 * @param connection
	 *            DHT Connection
	 */
	public static BusinessEntity select(String businessKey,
			DHTHandler connection) {

		org.apache.juddi.datastore.dht.datatype.BusinessEntity tmp = null;

		try {
			tmp = (org.apache.juddi.datastore.dht.datatype.BusinessEntity)  connection.retrieve(businessKey + " businessentity");
			 
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getBusiness();

	}

	/**
	 * Select all BusinessKeys from the business_entities table for a given
	 * 'publisherID' value.
	 * 
	 * @param publisherID
	 *            The user id of the BusinessEntity owner.
	 * @param connection
	 *            DHT connection
	 * @return Vector A Vector of BusinessKeys
	 */
	@SuppressWarnings("unchecked")
	public static Vector selectByPublisherID(String publisherID,
			DHTHandler connection) {
		Vector keyList = new Vector();
		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(publisherID + " businessentity");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			keyList
					.add(((org.apache.juddi.datastore.dht.datatype.BusinessEntity) it
							.next()).getBusiness());
		}

		return keyList;
	}

	/**
	 * Verify that 'publisherID' has the authority to update or delete
	 * BusinessEntity identified by the businessKey parameter
	 * 
	 * @param businessKey
	 * @param publisherID
	 * @param DHT
	 *            connection
	 */
	public static boolean verifyOwnership(String businessKey,
			String publisherID, DHTHandler connection) {
		if ((businessKey == null) || (publisherID == null))
			return false;

		boolean authorized = false;
		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(businessKey + " " + publisherID
					+ " businessentity");
			authorized = tmp.iterator().hasNext();
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return authorized;

	}

	/**
	 * Return the 'publisherID' for the BusinessEntity identified by the
	 * businessKey parameter. Retusn null if the business entity key does not
	 * represent a valid BuisnessEntity or if no publisherID is specified for
	 * that particular BusinessEntity.
	 * 
	 * @param businessKey
	 * @param connection
	 * @return publisherID or null if no publisherID is available.
	 * @throws java.sql.SQLException
	 */
	public static String selectPublisherID(String businessKey,
			DHTHandler connection) {
		if (businessKey == null)
			return null;

		org.apache.juddi.datastore.dht.datatype.BusinessEntity tmp = null;

		try {
			tmp = (org.apache.juddi.datastore.dht.datatype.BusinessEntity)connection.retrieve(businessKey + " businessentity");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getPublisherID();
	}
}
