/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.BusinessIdentifier;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class BusinessIdentifierTable {
	// private reference to the jUDDI logger
	// private static Log log =
	// LogFactory.getLog(BusinessIdentifierTable.class);

	static {

	}

	/**
	 * Insert new row into the BUSINESS_IDENTIFIER table.
	 * 
	 * @param businessKey
	 *            BusinessKey to the parent BusinessEntity object.
	 * @param keyRefs
	 *            A Vector of KeyedReference instances to insert.
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String businessKey, Vector keyRefs,
			DHTHandler connection) {

		BusinessIdentifier tmp = new BusinessIdentifier(businessKey, keyRefs);
		try {
			connection.insert(businessKey + " businessidentifier", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the BUSINESS_IDENTIFIER table for a given
	 * BusinessKey.
	 * 
	 * @param businessKey
	 *            BusinessKey
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String businessKey, DHTHandler connection) {
		BusinessIdentifier tmp = null;

		try {
			tmp = (BusinessIdentifier)connection.retrieve(businessKey + " businessidentifier");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getKeyRefs();

	}

	/**
	 * Delete multiple rows from the BUSINESS_IDENTIFIER table that are assigned
	 * to the BusinessKey specified.
	 * 
	 * @param businessKey
	 *            BusinessKey
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String businessKey, DHTHandler connection) {
		try {
			connection.remove("", businessKey + " businessidentifier");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
