/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.BusinessName;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class BusinessNameTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(BusinessNameTable.class);

	static {

	}

	/**
	 * Insert new row into the BUSINESS_NAME table.
	 * 
	 * @param businessKey
	 *            String to the BusinessEntity object that owns the Contact to
	 *            be inserted
	 * @param nameList
	 *            Vector of Phone objects holding values to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String businessKey, Vector nameList,
			DHTHandler connection) {
		if ((nameList == null) || (nameList.size() == 0))
			return; // everything is valid but no elements to insert

		BusinessName tmp = new BusinessName(businessKey, nameList);
		try{
		String txt="";
		Iterator it = nameList.iterator();
		while(it.hasNext()){
			txt+=" " + (String)it.next();
		}
		System.out.println("insert: " + businessKey + txt + " businessname");
		connection.insert(txt + " businessname", businessKey
				+ " businessname", tmp);
		
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the BUSINESS_NAME table for a given BusinessKey.
	 * 
	 * @param businessKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String businessKey, DHTHandler connection) {

		BusinessName tmp = null;

		try {
			tmp = (BusinessName)connection.retrieve(businessKey + " businessname");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getNameList();

	}

	/**
	 * Delete multiple rows from the BUSINESS_NAME table that are assigned to
	 * the BusinessKey specified.
	 * 
	 * @param businessKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String businessKey, DHTHandler connection) {
		try {
			connection.remove("", businessKey + " businessname");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
