/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.Contact;

import bunshin.util.ResultSortedQueue;
import dermi.DHTHandler;
import dermi.core.Id;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class ContactTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(ContactTable.class);

	static {

	}

	/**
	 * Insert new row into the CONTACT table.
	 * 
	 * @param businessKey
	 *            BusinessKey to the BusinessEntity object that owns the Contact
	 *            to be inserted
	 * @param contactList
	 *            Vector of Contact objects holding values to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String businessKey, Vector contactList,
			DHTHandler connection) {
		if ((contactList == null) || (contactList.size() == 0))
			return; // everything is valid but no elements to insert

		Contact tmp = new Contact(businessKey, contactList);
		try {
			connection.insert(businessKey + " contact", businessKey
					+ " contact", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the CONTACT table for a given BusinessKey.
	 * 
	 * @param businessKey
	 *            BusinessKey
	 * @param connection
	 *            JDBC connection
	 * @throws RemoteException 
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String businessKey, DHTHandler connection) {
		Vector contactList = new Vector();
		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(businessKey + " contact");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			try {
				contactList.add((Contact) connection.retrieve((Id)it.next()));
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		return contactList;

	}

	/**
	 * Delete multiple rows from the CONTACT table that are assigned to the
	 * BusinessKey specified.
	 * 
	 * @param businessKey
	 *            BusinessKey
	 * @param connection
	 *            JDBC connection
	 */
	public static void delete(String businessKey, DHTHandler connection) {
		try {
			connection.remove("", businessKey + " contact");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
