/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.DiscoveryURL;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class DiscoveryURLTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(DiscoveryURLTable.class);

	static {

	}

	/**
	 * Insert new row into the DISCOVERY_URL table.
	 * 
	 * @param businessKey
	 *            String to the BusinessEntity object that owns the Description
	 *            to be inserted
	 * @param urlList
	 *            Vector of Description objects holding values to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String businessKey, Vector urlList,
			DHTHandler connection) {
		if ((urlList == null) || (urlList.size() == 0))
			return; // everything is valid but no elements to insert

		DiscoveryURL tmp = new DiscoveryURL(businessKey, urlList);
		try {
			connection.insert( businessKey	+ " discoveryurl", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the DISCOVERY_URL table for a given BusinessKey.
	 * 
	 * @param businessKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String businessKey, DHTHandler connection) {

		DiscoveryURL tmp = null;

		try {
			tmp = (DiscoveryURL)connection.retrieve(businessKey + " discoveryurl");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getUrlList();
	}

	/**
	 * Delete multiple rows from the DISCOVERY_URL table that are assigned to
	 * the BusinessKey specified.
	 * 
	 * @param businessKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String businessKey, DHTHandler connection) {
		try {
			connection.remove("", businessKey + " discoveryurl");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
