/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.InstanceDetailsDesc;

import bunshin.util.ResultSortedQueue;
import dermi.DHTHandler;
import dermi.core.Id;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class InstanceDetailsDescTable {
	// private reference to the jUDDI logger
	// private static Log log =
	// LogFactory.getLog(InstanceDetailsDescTable.class);

	static {

	}

	/**
	 * Insert new row into the INSTANCE_DETAILS_DESCR table.
	 * 
	 * @param bindingKey
	 *            String to the BindingTemplate object
	 * @param tModelInstanceInfoID
	 *            String to the BusinessEntity object that owns the Contact to
	 *            be inserted
	 * @param descList
	 *            Vector of Description objects holding values to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String bindingKey, int tModelInstanceInfoID,
			Vector descList, DHTHandler connection) {
		if ((descList == null) || (descList.size() == 0))
			return; // everything is valid but no elements to insert

		InstanceDetailsDesc tmp = new InstanceDetailsDesc(bindingKey,
				tModelInstanceInfoID, descList);
		try {
			connection.insert(bindingKey + " " + tModelInstanceInfoID
					+ " instancedetailsdesc", bindingKey
					+ " instancedetailsdesc", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the TMODEL_INST_INFO table for a given BusinessKey.
	 * 
	 * @param bindingKey
	 *            String
	 * @param tModelInstanceInfoID
	 *            ID (sequence number) of the parent TModelInstanceInfo object
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String bindingKey, int tModelInstanceInfoID,
			DHTHandler connection) {
		Vector descList = new Vector();

		ResultSortedQueue tmp = null;

		try {
			String txt = "";
			if (bindingKey != ""){txt+=bindingKey + " ";}
			if (tModelInstanceInfoID != 0){txt+=tModelInstanceInfoID + " ";}
			tmp = connection.query(txt+ " instancedetailsdesc");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			try {
				descList.add((InstanceDetailsDesc) connection.retrieve((Id)it.next()));
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		return descList;

	}

	/**
	 * Delete multiple rows from the INSTANCE_DETAILS_DESCR table that are
	 * assigned to the BindingKey specified.
	 * 
	 * @param bindingKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String bindingKey, DHTHandler connection) {
		try {
			connection.remove("", bindingKey + " instancedetailsdesc");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
