/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datatype.KeyedReference;
import org.apache.juddi.datatype.assertion.PublisherAssertion;
import org.apache.juddi.datatype.response.AssertionStatusItem;
import org.apache.juddi.datatype.response.CompletionStatus;
import org.apache.juddi.datatype.response.KeysOwned;

import bunshin.util.ResultSortedQueue;
import dermi.DHTHandler;
import dermi.core.Id;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class PublisherAssertionTable {
	// private reference to the jUDDI logger
	// private static Log log =
	// LogFactory.getLog(PublisherAssertionTable.class);

	static {

	}

	/**
	 * Insert new row into the PUBLISHER_ASSERTION table.
	 * 
	 * @param assertion
	 *            Publisher Assertion object holding values to be inserted
	 * @param fromCheck
	 *            boolean true if the FROM_KEY is owned by the individual
	 *            'adding' this assertion (otherwise false).
	 * @param toCheck
	 *            boolean true if the TO_KEY is owned by the individual 'adding'
	 *            this assertion (otherwise false).
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(PublisherAssertion assertion, boolean fromCheck,
			boolean toCheck, DHTHandler connection) {

		org.apache.juddi.datastore.dht.datatype.PublisherAssertion tmp = new org.apache.juddi.datastore.dht.datatype.PublisherAssertion(
				assertion, toCheck, toCheck);
		try {
			connection.insert(assertion.getFromKey() + " "
					+ assertion.getToKey() + " publisherassertion", assertion
					.getFromKey()
					+ " " + assertion.getToKey() + " publisherassertion", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select one row from the PUBLISHER_ASSERTION table.
	 * 
	 * @param assertionIn
	 * @param DHT
	 *            connection
	 */
	public static PublisherAssertion select(PublisherAssertion assertionIn,
			DHTHandler connection) {
		PublisherAssertion assertionOut = null;

		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(assertionIn.getFromKey() + " "
					+ assertionIn.getToKey() + " publisherassertion");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		if (it.hasNext()) {
			try {
				assertionOut = ((org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id) it
						.next())).getAssertion();
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		return assertionOut;

	}

	/**
	 * Delete row from the PUBLISHER_ASSERTION table.
	 * 
	 */
	public static void deleteDeadAssertions(DHTHandler connection) {

		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(" publisherassertion");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			boolean from = false;
			try {
				from = ((org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id) it
						.next())).isFromCheck();
			} catch (RemoteException e1) {
				// TODO Auto-generated catch block
				e1.printStackTrace();
			}
			boolean to = false;
			try {
				to = ((org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id) it
						.next())).isToCheck();
			} catch (RemoteException e1) {
				// TODO Auto-generated catch block
				e1.printStackTrace();
			}
			if (from == false && to == false) {
				try {
					connection
							.remove(
									" publisherassertion",
									((org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id) it
											.next())).getAssertion()
											.getFromKey()
											+ " "
											+ ((org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id) it
													.next())).getAssertion()
													.getToKey());
				} catch (RemoteException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}

	}

	/**
	 * Update the FROM_CHECK column in the PUBLISHER_ASSERTION table for a
	 * particular PublisherAssertion.
	 * 
	 * @param assertion
	 *            The PublisherAssertion to update BusinessKey
	 * @param fromCheck
	 *            The value to set the FROM_CHECK column to.
	 * @param connection
	 *            DHT connection
	 */
	public static void updateFromCheck(PublisherAssertion assertion,
			boolean fromCheck, DHTHandler connection) {

		try {
			org.apache.juddi.datastore.dht.datatype.PublisherAssertion tmp = (org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection
					.retrieve(assertion.getFromKey() + " "
							+ assertion.getToKey() + " publisherassertion");
			tmp.setFromCheck(fromCheck);
			connection.insert(assertion.getFromKey() + " "
					+ assertion.getToKey() + " publisherassertion", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Update the TO_CHECK column in the PUBLISHER_ASSERTION table for a
	 * particular PublisherAssertion.
	 * 
	 * @param assertion
	 *            The PublisherAssertion to update BusinessKey
	 * @param toCheck
	 *            The value to set the TO_CHECK column to.
	 * @param connection
	 *            DHT connection
	 */
	public static void updateToCheck(PublisherAssertion assertion,
			boolean toCheck, DHTHandler connection) {

		try {
			org.apache.juddi.datastore.dht.datatype.PublisherAssertion tmp = (org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection
					.retrieve(assertion.getFromKey() + " "
							+ assertion.getToKey());
			tmp.setToCheck(toCheck);
			connection.insert(assertion.getFromKey() + " "
					+ assertion.getToKey(), tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Update the FROM_CHECK column for all rows from in the PUBLISHER_ASSERTION
	 * table whose FROM_KEY is in the Vector of BusinessKeys passed in.
	 * 
	 * @param fromKeysIn
	 *            A Vector of BusinessKeys to update
	 * @param fromCheck
	 *            The value to set the FROM_CHECK column to
	 * @param connection
	 *            DHT connection
	 */
	public static void updateFromCheckByFromKey(Vector fromKeysIn,
			boolean fromCheck, DHTHandler connection) {
		/*
		 * "UPDATE PUBLISHER_ASSERTION " "SET FROM_CHECK=? " "WHERE FROM_KEY IN "
		 */
		ResultSortedQueue tmp = null;
		Iterator it = fromKeysIn.iterator();
		while (it.hasNext()) {
			try {
				tmp = connection.query(it.next().toString()
						+ " publisherassertion");
				Iterator it2 = tmp.iterator();
				while (it2.hasNext()) {
					org.apache.juddi.datastore.dht.datatype.PublisherAssertion pa = (org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id)it2.next());
					pa.setFromCheck(fromCheck);
					connection.retrieve(pa.getAssertion().getFromKey() + " "
							+ pa.getAssertion().getToKey()
							+ " publisherassertion");
					connection.insert(pa.getAssertion().getFromKey() + " "
							+ pa.getAssertion().getToKey()
							+ " publisherassertion", pa);
				}
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

	}

	/**
	 * Update the TO_CHECK column for all rows from in the PUBLISHER_ASSERTION
	 * table whose TO_KEY is in the Vector of BusinessKeys passed in.
	 * 
	 * @param toKeysIn
	 *            A Vector of BusinessKeys to update
	 * @param toCheck
	 *            The value to set the TO_KEY column to
	 * @param connection
	 *            DHT connection
	 */
	public static void updateToCheckByToKey(Vector toKeysIn, boolean toCheck,
			DHTHandler connection) {
		/*
		 * "UPDATE PUBLISHER_ASSERTION " "SET TO_CHECK=? " "WHERE TO_KEY IN "
		 */

		ResultSortedQueue tmp = null;
		Iterator it = toKeysIn.iterator();
		while (it.hasNext()) {
			try {
				tmp = connection.query(it.next().toString()
						+ " publisherassertion");
				Iterator it2 = tmp.iterator();
				while (it2.hasNext()) {
					org.apache.juddi.datastore.dht.datatype.PublisherAssertion pa = (org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id)it2.next());
					pa.setToCheck(toCheck);
					connection.retrieve(pa.getAssertion().getFromKey() + " "
							+ pa.getAssertion().getToKey()
							+ " publisherassertion");
					connection.insert(pa.getAssertion().getFromKey() + " "
							+ pa.getAssertion().getToKey()
							+ " publisherassertion", pa);
				}
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}

	/**
	 * Select any rows from the PUBLISHER_ASSERTION table where the FROM_KEY or
	 * TO_KEY column value is found in the Vector of BusinessKeys passed in and
	 * return the results as a Vector of assertionStatusItem instances.
	 * 
	 * The assertionStatusItems returned represent PublisherAssertions in which
	 * the fromKey and toKey are both are under the control of a particular
	 * Publisher.
	 * 
	 * NOTE: Each AssertionStatusItem returned from this method will have a
	 * completion stauts of 'status:complete' because only assertions in which
	 * both business entities are managed (was published) by same publisher.
	 * 
	 * @param keysIn
	 *            Vector business keys to look for in the FROM_KEY and TO_KEY
	 *            column.
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector selectBothKeysOwnedAssertion(Vector keysIn,
			DHTHandler connection) {
		if ((keysIn == null) || (keysIn.size() == 0))
			return null;

		ResultSortedQueue tmp = null;
		Vector itemList = new Vector();
		Iterator it = keysIn.iterator();

		while (it.hasNext()) {
			try {
				tmp = connection.query(it.next().toString()
						+ " publisherassertion");
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			Iterator it2 = tmp.iterator();
			while (it2.hasNext()) {
				org.apache.juddi.datastore.dht.datatype.PublisherAssertion pa = null;
				try {
					pa = (org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id)it2.next());
				} catch (RemoteException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
				if (pa.getAssertion().getToKey() == pa.getAssertion()
						.getFromKey()) {
					AssertionStatusItem item = new AssertionStatusItem();
					item.setFromKey(pa.getAssertion().getFromKey()); // ("FROM_KEY"));
					item.setToKey(pa.getAssertion().getToKey()); // ("TO_KEY"));

					// construct and set the KeyedReference instance
					KeyedReference keyedRef = new KeyedReference();
					keyedRef.setTModelKey(pa.getAssertion().getTModelKey()); // ("TMODEL_KEY"));
					keyedRef.setKeyName(pa.getAssertion().getKeyName()); // ("KEY_NAME"));
					keyedRef.setKeyValue(pa.getAssertion().getKeyValue()); // ("KEY_VALUE"));
					item.setKeyedReference(keyedRef);

					// construct and set the KeysOwned instance
					KeysOwned keysOwned = new KeysOwned();
					keysOwned.setFromKey(item.getFromKey());
					keysOwned.setToKey(item.getToKey());
					item.setKeysOwned(keysOwned);

					// determine & set the 'completionStatus' (always
					// 'status:complete' here)
					item.setCompletionStatus(new CompletionStatus(
							CompletionStatus.COMPLETE));

					// add the assertionStatusItem
					itemList.addElement(item);
				}
			}
		}
		return itemList;

	}

	/**
	 * Select any rows from the PUBLISHER_ASSERTION table where the FROM_KEY
	 * column DOES CONTAIN one of the business keys found in the Vector of keys
	 * passed in and the TO_KEY column DOES NOT CONTAIN one of the business keys
	 * from the same Vector of keys. Return the results as a Vector of
	 * assertionStatusItem instances.
	 * 
	 * The assertionStatusItems returned represent PublisherAssertions in which
	 * ONLY the "fromKey" is under the control of a particular Publisher.
	 * 
	 * @param keysIn
	 *            Vector business keys to look for in the FROM_KEY and TO_KEY
	 *            column.
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector selectFromKeyOwnedAssertion(Vector keysIn,
			DHTHandler connection) {
		if ((keysIn == null) || (keysIn.size() == 0))
			return null;

		ResultSortedQueue tmp = null;
		Vector itemList = new Vector();
		Iterator it = keysIn.iterator();
		String num = "";
		while (it.hasNext()) {
			try {
				num = it.next().toString();
				tmp = connection.query(num + " publisherassertion");
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			Iterator it2 = tmp.iterator();
			while (it2.hasNext()) {
				org.apache.juddi.datastore.dht.datatype.PublisherAssertion pa = null;
				try {
					pa = (org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id)it2.next());
				} catch (RemoteException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
				if (pa.getAssertion().getToKey() != num) {
					AssertionStatusItem item = new AssertionStatusItem();
					item.setFromKey(pa.getAssertion().getFromKey()); // ("FROM_KEY"));
					item.setToKey(pa.getAssertion().getToKey()); // ("TO_KEY"));

					// construct and set the KeyedReference instance
					KeyedReference keyedRef = new KeyedReference();
					keyedRef.setTModelKey(pa.getAssertion().getTModelKey()); // ("TMODEL_KEY"));
					keyedRef.setKeyName(pa.getAssertion().getKeyName()); // ("KEY_NAME"));
					keyedRef.setKeyValue(pa.getAssertion().getKeyValue()); // ("KEY_VALUE"));
					item.setKeyedReference(keyedRef);

					// construct and set the KeysOwned instance
					KeysOwned keysOwned = new KeysOwned();
					keysOwned.setFromKey(item.getFromKey());
					keysOwned.setToKey(item.getToKey());
					item.setKeysOwned(keysOwned);

					// determine & set the 'completionStatus' (always
					// 'status:complete' here)
					item.setCompletionStatus(new CompletionStatus(
							CompletionStatus.COMPLETE));

					// add the assertionStatusItem
					itemList.addElement(item);
				}
			}
		}
		return itemList;

	}

	/**
	 * Select any rows from the PUBLISHER_ASSERTION table where the FROM_KEY
	 * column DOES NOT CONTAIN one of the business keys found in the Vector of
	 * keys passed in and the TO_KEY column DOES CONTAIN one of the business
	 * keys from the same Vector of keys. Return the results as a Vector of
	 * assertionStatusItem instances.
	 * 
	 * The assertionStatusItems returned represent PublisherAssertions in which
	 * ONLY the "toKey" is under the control of a particular Publisher.
	 * 
	 * @param keysIn
	 *            Vector business keys to look for in the FROM_KEY and TO_KEY
	 *            column.
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector selectToKeyOwnedAssertion(Vector keysIn,
			DHTHandler connection) {
		if ((keysIn == null) || (keysIn.size() == 0))
			return null;

		ResultSortedQueue tmp = null;
		Vector itemList = new Vector();
		Iterator it = keysIn.iterator();
		String num = "";
		while (it.hasNext()) {
			try {
				num = it.next().toString();
				tmp = connection.query(num + " publisherassertion");
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			Iterator it2 = tmp.iterator();
			while (it2.hasNext()) {
				org.apache.juddi.datastore.dht.datatype.PublisherAssertion pa = null;
				try {
					pa = (org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id)it2.next());
				} catch (RemoteException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
				if (pa.getAssertion().getFromKey() != num) {
					AssertionStatusItem item = new AssertionStatusItem();
					item.setFromKey(pa.getAssertion().getFromKey()); // ("FROM_KEY"));
					item.setToKey(pa.getAssertion().getToKey()); // ("TO_KEY"));

					// construct and set the KeyedReference instance
					KeyedReference keyedRef = new KeyedReference();
					keyedRef.setTModelKey(pa.getAssertion().getTModelKey()); // ("TMODEL_KEY"));
					keyedRef.setKeyName(pa.getAssertion().getKeyName()); // ("KEY_NAME"));
					keyedRef.setKeyValue(pa.getAssertion().getKeyValue()); // ("KEY_VALUE"));
					item.setKeyedReference(keyedRef);

					// construct and set the KeysOwned instance
					KeysOwned keysOwned = new KeysOwned();
					keysOwned.setFromKey(item.getFromKey());
					keysOwned.setToKey(item.getToKey());
					item.setKeysOwned(keysOwned);

					// determine & set the 'completionStatus' (always
					// 'status:complete' here)
					item.setCompletionStatus(new CompletionStatus(
							CompletionStatus.COMPLETE));

					// add the assertionStatusItem
					itemList.addElement(item);
				}
			}
		}
		return itemList;

	}

	/**
	 * Select any rows from the PUBLISHER_ASSERTION table where the FROM_KEY
	 * column CONTAINS one of the business keys found in the Vector of keys
	 * passed in OR the TO_KEY column CONTAINS one of the business keys from the
	 * same Vector f keys. Return the results as a Vector of PublisherAssertion
	 * instances.
	 * 
	 * @param keysIn
	 *            Vector business keys to look for in the FROM_KEY and TO_KEY
	 *            column.
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector selectAssertions(Vector keysIn, DHTHandler connection) {
		if ((keysIn == null) || (keysIn.size() == 0))
			return null;

		ResultSortedQueue tmp = null;
		Vector assertionList = new Vector();
		Iterator it = keysIn.iterator();
		while (it.hasNext()) {
			try {
				tmp = connection.query(it.next().toString()
						+ " publisherassertion");
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			Iterator it2 = tmp.iterator();
			while (it2.hasNext()) {
				org.apache.juddi.datastore.dht.datatype.PublisherAssertion pa = null;
				try {
					pa = (org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id)it2.next());
				} catch (RemoteException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}

				if (pa.isFromCheck() == true && pa.isToCheck() == true) {
					PublisherAssertion assertion = new PublisherAssertion();
					assertion.setFromKey(pa.getAssertion().getFromKey());// ("FROM_KEY"));
					assertion.setToKey(pa.getAssertion().getToKey());// ("TO_KEY"));

					// construct and set the KeyedReference instance
					KeyedReference keyedRef = new KeyedReference();
					keyedRef.setTModelKey(pa.getAssertion().getTModelKey()); // ("TMODEL_KEY"));
					keyedRef.setKeyName(pa.getAssertion().getKeyName()); // ("KEY_NAME"));
					keyedRef.setKeyValue(pa.getAssertion().getKeyValue()); // ("KEY_VALUE"));
					assertion.setKeyedReference(keyedRef);

					// add the assertionStatusItem
					assertionList.addElement(assertion);
				}

			}
		}

		return assertionList;

	}

	/**
	 * Retrieve the TMODEL_KEY, KEY_NAME and KEY_VALUE from all assertions where
	 * the FROM_KEY = businessKey and the TO_KEY = relatedBusinessKey parameters
	 * or the FROM_KEY = relatedBusinessKey and the TO_KEY = businessKey.
	 * 
	 * @param businessKey
	 *            The BusinessKey we're searching for relationships to.
	 * @param relatedKey
	 *            The BusinessKey of the related BusinessEntity.
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector selectRelatedBusinesses(String businessKey,
			String relatedKey, DHTHandler connection) {
		Vector refList = new Vector();
		ResultSortedQueue tmp = null;
		try {
			tmp = connection.query(businessKey + " " + relatedKey
					+ " publisherassertion");
		} catch (RemoteException e) {
			e.printStackTrace();
		}
		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			org.apache.juddi.datastore.dht.datatype.PublisherAssertion pa = null;
			try {
				pa = (org.apache.juddi.datastore.dht.datatype.PublisherAssertion) connection.retrieve((Id)it.next());
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
			if (pa.isFromCheck() == true && pa.isToCheck() == true) {
				KeyedReference keyedRef = new KeyedReference();
				keyedRef.setTModelKey(pa.getAssertion().getTModelKey()); // ("TMODEL_KEY"));
				keyedRef.setKeyName(pa.getAssertion().getKeyName()); // ("KEY_NAME"));
				keyedRef.setKeyValue(pa.getAssertion().getKeyValue()); // ("KEY_VALUE"));

				// add the KeyedRef to the Vector
				refList.addElement(keyedRef);
			}
		}

		return refList;
	}

}
