/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import org.apache.juddi.datatype.publisher.Publisher;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
 public class PublisherTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(PublisherTable.class);

	static {

	}

	/**
	 * Insert new row into the PUBLISHER table.
	 * 
	 * @param publisher
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(Publisher publisher, DHTHandler connection) {
		if (publisher == null) {
			return;
		}

		try {
			connection.insert(publisher.getPublisherID()+ " publisher", publisher);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select one row from the PUBLISHER table.
	 * 
	 * @param publisherID
	 * @param connection
	 *            DHT connection
	 * @return Publisher
	 */
	public static Publisher select(String publisherID, DHTHandler connection) {
		// return 'null' if a null publisherID is specified.
		if (publisherID == null)
			return null;

		Publisher p = null;

		try {
			p = (Publisher)connection.retrieve(publisherID + " publisher");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return p;
	}

	/**
	 * Delete row from the PUBLISHER table.
	 * 
	 * @param publisherID
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String publisherID, DHTHandler connection) {
		try {
			connection.remove("", publisherID+ " publisher");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Update the PUBLISHER table for a particular PublisherID.
	 * 
	 * @param publisher
	 * @param connection
	 *            DHT connection
	 */
	public static void update(Publisher publisher, DHTHandler connection) {

		try {
			connection.remove("",publisher.getPublisherID()+ " publisher");
			connection.insert(publisher.getPublisherID()+ " publisher", publisher);
		} catch (RemoteException e) {
			e.printStackTrace();
		}
	}
}