/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Vector;

import org.apache.juddi.datastore.dht.datatype.TModelInstanceInfo;

import dermi.DHTHandler;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class TModelInstanceInfoTable {
	// private reference to the jUDDI logger
	// private static Log log =
	// LogFactory.getLog(TModelInstanceInfoTable.class);

	static {

	}

	/**
	 * Insert new row into the TMODEL_INSTANCE_INFO table.
	 * 
	 * @param bindingKey
	 *            String to the BusinessEntity object that owns the Contact to
	 *            be inserted
	 * @param infoList
	 *            Vector of Contact objects holding values to be inserted
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(String bindingKey, Vector infoList,
			DHTHandler connection) {
		if ((infoList == null) || (infoList.size() == 0))
			return; // everything is valid but no elements to insert

		TModelInstanceInfo tmp = new TModelInstanceInfo(bindingKey, infoList);
		try {
			connection.insert(bindingKey+ " tmodelinstanceinfo", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select all rows from the TMODEL_INST_INFO table for a given BusinessKey.
	 * 
	 * @param bindingKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector select(String bindingKey, DHTHandler connection) {

		TModelInstanceInfo tmp = null;

		try {
			tmp = (TModelInstanceInfo)connection.retrieve(bindingKey + " tmodelinstanceinfo");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getInfoList();

	}

	/**
	 * Delete multiple rows from the TMODEL_INST_INFO table that are assigned to
	 * the BusinessKey specified.
	 * 
	 * @param bindingKey
	 *            String
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String bindingKey, DHTHandler connection) {
		try {
			connection.remove("", bindingKey + " tmodelinstanceinfo");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
