/*
 * Copyright 2001-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.datastore.dht;

import java.util.Iterator;
import java.util.Vector;

import org.apache.juddi.datatype.tmodel.TModel;

import bunshin.util.ResultSortedQueue;
import dermi.DHTHandler;
import dermi.core.Id;
import dermi.exception.RemoteException;

/**
 * @author Oscar Barrios (oscar.barrios@estudiants.urv.es)
 */
public class TModelTable {
	// private reference to the jUDDI logger
	// private static Log log = LogFactory.getLog(TModelTable.class);

	static {
	}

	/**
	 * Insert new row into the TMODEL table.
	 * 
	 * @param tModel
	 *            TModel object holding values to be inserted
	 * @param publisherID
	 * @param connection
	 *            DHT connection
	 */
	public static void insert(TModel tModel, String publisherID,
			DHTHandler connection) {

		org.apache.juddi.datastore.dht.datatype.TModel tmp = new org.apache.juddi.datastore.dht.datatype.TModel(
				tModel, publisherID);
		try {
			connection.insert(tModel.getTModelKey() + " " + publisherID
					+ " tmodel", tModel.getTModelKey() + " tmodel", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Delete row from the TMODEL table.
	 * 
	 * @param tModelKey
	 * @param connection
	 *            DHT connection
	 */
	public static void delete(String tModelKey, DHTHandler connection) {
		try {
			connection.remove("", tModelKey + " tmodel");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Update the TMODEL table setting the value of the DELETED column to
	 * 'true'.
	 * 
	 * @param tModelKey
	 * @param connection
	 *            DHT connection
	 */
	public static void markAsDeleted(String tModelKey, DHTHandler connection) {
		try {
			org.apache.juddi.datastore.dht.datatype.TModel tmp = (org.apache.juddi.datastore.dht.datatype.TModel) connection
					.retrieve(tModelKey + " tmodel");
			tmp.setDelete(true);
			connection.insert(tModelKey + " tmodel", tmp);
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	/**
	 * Select one row from the TMODEL table.
	 * 
	 * @param tModelKey
	 * @param DHT
	 *            connection
	 */
	public static TModel select(String tModelKey, DHTHandler connection) {
		org.apache.juddi.datastore.dht.datatype.TModel tmp = null;

		try {
			tmp = (org.apache.juddi.datastore.dht.datatype.TModel)connection.retrieve(tModelKey + " tmodel");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return tmp.getTModel();

	}

	/**
	 * Select all TModelKeys from the business_entities table for a given
	 * 'publisherID' value.
	 * 
	 * @param publisherID
	 *            The User ID of the TModel owner.
	 * @param connection
	 *            DHT connection
	 */
	@SuppressWarnings("unchecked")
	public static Vector selectByPublisherID(String publisherID,
			DHTHandler connection) {
		Vector keyList = new Vector();

		ResultSortedQueue tmp = null;

		try {
			tmp = connection.query(publisherID + " tmodel");
		} catch (RemoteException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		Iterator it = tmp.iterator();
		while (it.hasNext()) {
			try {
				keyList.add((((org.apache.juddi.datastore.dht.datatype.TModel) connection.retrieve((Id)it
						.next()))).getTModel());
			} catch (RemoteException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		return keyList;

	}

	/**
	 * Verify that 'publisherID' has the authority to update or delete TModel
	 * identified by the tModelKey parameter
	 * 
	 * @param tModelKey
	 * @param publisherID
	 * @param DHT
	 *            connection
	 */
	public static boolean verifyOwnership(String tModelKey, String publisherID,
			DHTHandler connection) {
		if ((tModelKey == null) || (publisherID == null))
			return false;

		boolean authorized = false;
		ResultSortedQueue tmp = null;

		/*
		 * "SELECT * " "FROM TMODEL " "WHERE TMODEL_KEY=? " "AND PUBLISHER_ID=? "
		 * "AND DELETED IS NULL"
		 */

		try {
			tmp = connection.query(tModelKey + " " + publisherID + " tmodel");
			org.apache.juddi.datastore.dht.datatype.TModel tm = (org.apache.juddi.datastore.dht.datatype.TModel) connection.retrieve((Id)tmp
					.iterator().next());
			if (tm.getDelete() == false) {
				authorized = true;
			} else {
				authorized = false;
			}
		} catch (RemoteException e) {
			e.printStackTrace();
		}

		return authorized;

	}
}
