/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.juddi.handler;

import org.apache.juddi.datatype.Description;
import org.apache.juddi.datatype.OverviewDoc;
import org.apache.juddi.datatype.RegistryObject;
import org.apache.juddi.datatype.binding.AccessPoint;
import org.apache.juddi.datatype.binding.BindingTemplate;
import org.apache.juddi.datatype.binding.HostingRedirector;
import org.apache.juddi.datatype.binding.InstanceDetails;
import org.apache.juddi.datatype.binding.TModelInstanceDetails;
import org.apache.juddi.datatype.binding.TModelInstanceInfo;
import org.apache.juddi.util.xml.XMLUtils;
import org.w3c.dom.Element;

/**
 * @author anou_mana@apache.org
 */
public class BindingTemplateHandlerTests extends HandlerTestCase {
	private static final String TEST_ID = "juddi.handler.BindingTemplate.test";

	private BindingTemplateHandler handler = null;

	public BindingTemplateHandlerTests(String arg0) {
		super(arg0);
	}

	public static void main(String[] args) {
		junit.textui.TestRunner.run(BindingTemplateHandlerTests.class);
	}

	public void setUp() {
		HandlerMaker maker = HandlerMaker.getInstance();
		handler = (BindingTemplateHandler) maker
				.lookup(BindingTemplateHandler.TAG_NAME);
	}

	private RegistryObject getRegistryObject() {

		OverviewDoc overDoc = new OverviewDoc();
		overDoc.setOverviewURL("http://www.juddi.org/service.html");
		overDoc.addDescription(new Description("over-doc Descr"));
		overDoc.addDescription(new Description("over-doc Descr Two", "en"));

		InstanceDetails instDetails = new InstanceDetails();
		instDetails.addDescription(new Description("inst-det descr"));
		instDetails.addDescription(new Description("inst-det descr in italy",
				"it"));
		instDetails.setInstanceParms("inst-det parameters");
		instDetails.setOverviewDoc(overDoc);

		TModelInstanceInfo tModInstInfo = new TModelInstanceInfo();
		tModInstInfo.setTModelKey("uuid:ae0f9fd4-287f-40c9-be91-df47a7c72fd9");
		tModInstInfo.addDescription(new Description("tMod-Inst-Info"));
		tModInstInfo
				.addDescription(new Description("tMod-Inst-Info too", "es"));
		tModInstInfo.setInstanceDetails(instDetails);

		TModelInstanceDetails tModInstDet = new TModelInstanceDetails();
		tModInstDet.addTModelInstanceInfo(tModInstInfo);

		BindingTemplate object = new BindingTemplate();
		object.setBindingKey("c9613c3c-fe55-4f34-a3da-b3167afbca4a");
		object.setServiceKey("997a55bc-563d-4c04-8a94-781604870d31");
		object.addDescription(new Description("whatever"));
		object.addDescription(new Description("whatever too", "fr"));
		object.setHostingRedirector(new HostingRedirector(
				"92658289-0bd7-443c-8948-0bb4460b44c0"));
		object.setAccessPoint(new AccessPoint(AccessPoint.HTTP,
				"http://www.juddi.org/service.wsdl"));
		object.setTModelInstanceDetails(tModInstDet);

		return object;

	}

	private Element getMarshalledElement(RegistryObject regObject) {
		Element parent = XMLUtils.newRootElement();
		Element child = null;

		if (regObject == null)
			regObject = this.getRegistryObject();

		handler.marshal(regObject, parent);
		child = (Element) parent.getFirstChild();
		parent.removeChild(child);

		return child;
	}

	public void testMarshal() {
		Element child = getMarshalledElement(null);

		String marshalledString = this.getXMLString(child);

		assertNotNull("Marshalled BindingTemplate ", marshalledString);

	}

	public void testUnMarshal() {

		Element child = getMarshalledElement(null);
		RegistryObject regObject = handler.unmarshal(child);

		assertNotNull("UnMarshalled BindingTemplate ", regObject);

	}

	public void testMarshUnMarshal() {
		Element child = getMarshalledElement(null);

		String marshalledString = this.getXMLString(child);

		assertNotNull("Marshalled BindingTemplate ", marshalledString);

		RegistryObject regObject = handler.unmarshal(child);

		child = getMarshalledElement(regObject);

		String unMarshalledString = this.getXMLString(child);

		assertNotNull("Unmarshalled BindingTemplate ", unMarshalledString);

		boolean equals = marshalledString.equals(unMarshalledString);

		assertEquals("Expected result: ", marshalledString, unMarshalledString);
	}

}
